<?php

require_once __DIR__ .'/../lib/phpoaipmh/vendor/autoload.php';

abstract class OaiImport {
  public $endPointUrl;
  public $client;
  public $endPoint;
  public $uploader; // how upload resources owner
  public $rootCatalogNode; // root node, where content is imported
  function __construct($endPointUrl) {
    
    $this->endPointUrl = $endPointUrl;
    $this->client = new \Phpoaipmh\Client($this->endPointUrl);
    $this->endPoint = new \Phpoaipmh\Endpoint($this->client);
    $this->endPoint->identify();
    
    $this->uploader = $GLOBALS['user'];
  }
  
  abstract public function importRecord($identifier);
  
  public function getRecord($identifier) {
    $fullrec = $this->endPoint->getRecord($identifier, 'oai_dc');
    $record_url = $this->endPointUrl . '?verb=GetRecord&metadataPrefix=oai_dc&identifier=' . $identifier;
    $file = file_get_contents($record_url);
    $dom = new DomDocument();
    $dom->loadXML($file);
    return $dom;
  }
  
  public function getNodeForRecord($identifier) {
    
    $dom = $this->getRecord($identifier);
    
    $uploader = $this->uploader ? $this->uploader : $GLOBALS['user'];
    $node = new stdClass();
    $node->type = "ebook";
    node_object_prepare($node);
    $node->language = LANGUAGE_NONE;
    $node->uid = $uploader->uid;
    $node->status = 1;
    $node->promote = 0;
    $node->comment = 0;
    // return $node;
    
    $x = $dom->documentElement;
    //foreach ($x->childNodes as $xmlNode) {
      // print $xmlNode->nodeName . "\n";
    //}
    $this->addRecordIdentifier($node, $dom, $identifier);
    $this->addRecordTitle($node, $dom, $identifier);
    $this->addRecordAuthors($node, $dom, $identifier);
    $this->addRecordDescription($node, $dom, $identifier);
    $this->addRecordLicense($node, $dom, $identifier);
    return $node;
  }
  
  protected function addRecordTitle(&$node, &$dom, $identifier) {
    $titles = $dom->getElementsByTagName('title');
    foreach ($titles as $title) {
      $node->title = $title->nodeValue;
    }
  }
  
  protected function addRecordAuthors(&$node, &$dom, $identifier) {
    $creators = $dom->getElementsByTagName('creator');
    $authors = array();
    foreach ($creators as $creator) {
      $authors[] = $creator->nodeValue;
    }
    ElisImportHelper::attachAuthorsToNode($node,$authors);
  }
  
  protected function addRecordDescription(&$node, &$dom, $identifier) {
    $descriptions = $dom->getElementsByTagName('description');
    $body = false;
    foreach ($descriptions as $description) {
      $body = $description->nodeValue;
    }
    if ($body != false) ElisImportHelper::attachBodyToNode($node,$body);
  }
  
  /**
   * Must extract license url and add it to node->field_license
   */
  protected function addRecordLicense(&$node, &$dom, $identifier) {
    $license_url = false;
    if ($license_url) {
      ElisImportHelper::attachLicenseUrlToNode($node, $license_url);
    }
  }
  
  protected function addRecordIdentifier(&$node, &$dom, $identifier) {
    ElisImportHelper::attachIdentifierToNode($node, $identifier);
  }
    
  /**
   * Helper method for find in xpath the meta tag content value and return it as string or false
   * Usage: 
   *   $dom = new DomDocument();
   *   $dom->loadHTML($resourcePage);
   *   $xpath = new DOMXPath($dom);
   *   $cirtation_pdf_url = $this->findMetaContentFromXpath('citation_pdf_url', $xpath);
   * @param String $metaTagName like 'citation_issn', 'eprints.abstract'
   * @param DOMXPath $xpath
   * @return mixed out inside <meta name="$metaTagName" content=""/> or false
   */
  protected function findMetaContentFromXpath($metaTagName,$xpath) {
    $out = false;
    $elements = $xpath->query("//meta[@name='$metaTagName']");
    if (!is_null($elements)) {
      foreach ($elements as $element) {
        $content = $element->getAttribute('content');
        if ($content != false && $content != '') {
          $out = $content;
        }
      }
    }
    return $out;
  }
  
  public function findCanonicalUrlFromXpath($xpath) {
    $out = false;
    $elements = $xpath->query("//link[@rel='canonical']");
    if (!is_null($elements)) {
      foreach ($elements as $element) {
        $content = filter_var($element->getAttribute('href'), FILTER_VALIDATE_URL);
        if ($content != false && $content != '') {
          $out = $content;
        }
      }
    }
    if (!$out) {
      $elements = $xpath->query("//meta[@property='og:url']");  
      if (!is_null($elements)) {
        foreach ($elements as $element) {
          $content = filter_var($element->getAttribute('content'), FILTER_VALIDATE_URL);
          if ($content != false && $content != '') {
            $out = $content;
          }
        }
      }
    }
    return $out;
  }
}

